@@ -3,9 +3,7 @@ import boto3 as boto
 
 class S3Client(object):
     def __init__(self, bucket_name):
-        self.client = boto.resource('s3',
-            aws_access_key_id = 'AKIAYU3L4PNIAG2VIUWY',
-            aws_secret_access_key = '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')
+        self.client = boto.resource('s3')
         self.bucket_name = bucket_name
 
     def __create_bucket(self):
